package cofh.thermal.expansion.block.entity.machine;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import cofh.core.util.helpers.AugmentableHelper;
import cofh.core.util.helpers.ItemHelper;
import cofh.lib.api.StorageGroup;
import cofh.lib.api.inventory.IItemStackHolder;
import cofh.lib.client.sounds.ConditionalSoundInstance;
import cofh.lib.inventory.ItemStorageCoFH;
import cofh.lib.util.helpers.MathHelper;
import cofh.thermal.core.config.ThermalCoreConfig;
import cofh.thermal.core.util.managers.machine.SmelterRecipeManager;
import cofh.thermal.expansion.init.TExpSounds;
import cofh.thermal.expansion.init.TExpTileEntities;
import cofh.thermal.expansion.inventory.container.machine.MachineSmelterContainer;
import cofh.thermal.lib.block.entity.MachineBlockEntity;
import cofh.thermal.lib.util.recipes.IMachineInventory;
import cofh.thermal.lib.util.recipes.IThermalInventory;
import java.util.List;
import javax.annotation.Nullable;
import net.minecraft.core.BlockPos;
import net.minecraft.nbt.CompoundTag;
import net.minecraft.sounds.SoundEvent;
import net.minecraft.sounds.SoundSource;
import net.minecraft.world.entity.player.Inventory;
import net.minecraft.world.entity.player.Player;
import net.minecraft.world.inventory.AbstractContainerMenu;
import net.minecraft.world.item.ItemStack;
import net.minecraft.world.level.block.entity.BlockEntity;
import net.minecraft.world.level.block.entity.BlockEntityType;
import net.minecraft.world.level.block.state.BlockState;

public class MachineSmelterTile extends MachineBlockEntity {
  protected ItemStorageCoFH[] inputSlots = new ItemStorageCoFH[3];
  
  protected ItemStorageCoFH catalystSlot;
  
  protected boolean cyclicProcessingFeature;
  
  public MachineSmelterTile(BlockPos pos, BlockState state) {
    super((BlockEntityType)TExpTileEntities.MACHINE_SMELTER_TILE.get(), pos, state);
    this.catalystSlot = new ItemStorageCoFH(item -> (item.m_41720_() instanceof cofh.thermal.core.item.SlotSealItem || (SmelterRecipeManager.instance().validCatalyst(item) && !ItemHelper.itemsEqual(item, this.inputSlots[0].getItemStack()) && !ItemHelper.itemsEqual(item, this.inputSlots[1].getItemStack()) && !ItemHelper.itemsEqual(item, this.inputSlots[2].getItemStack()))));
    this.cyclicProcessingFeature = false;
    this.inputSlots[0] = new ItemStorageCoFH(item -> (item.m_41720_() instanceof cofh.thermal.core.item.SlotSealItem || (this.filter.valid(item) && SmelterRecipeManager.instance().validItem(item) && !ItemHelper.itemsEqual(item, this.inputSlots[1].getItemStack()) && !ItemHelper.itemsEqual(item, this.inputSlots[2].getItemStack()) && !ItemHelper.itemsEqual(item, this.catalystSlot.getItemStack()))));
    this.inputSlots[1] = new ItemStorageCoFH(item -> (item.m_41720_() instanceof cofh.thermal.core.item.SlotSealItem || (this.filter.valid(item) && SmelterRecipeManager.instance().validItem(item) && !ItemHelper.itemsEqual(item, this.inputSlots[0].getItemStack()) && !ItemHelper.itemsEqual(item, this.inputSlots[2].getItemStack()) && !ItemHelper.itemsEqual(item, this.catalystSlot.getItemStack()))));
    this.inputSlots[2] = new ItemStorageCoFH(item -> (item.m_41720_() instanceof cofh.thermal.core.item.SlotSealItem || (this.filter.valid(item) && SmelterRecipeManager.instance().validItem(item) && !ItemHelper.itemsEqual(item, this.inputSlots[0].getItemStack()) && !ItemHelper.itemsEqual(item, this.inputSlots[1].getItemStack()) && !ItemHelper.itemsEqual(item, this.catalystSlot.getItemStack()))));
    for (int i = 0; i < 3; i++)
      this.inventory.addSlot(this.inputSlots[i], StorageGroup.INPUT); 
    this.inventory.addSlot(this.catalystSlot, StorageGroup.CATALYST);
    this.inventory.addSlots(StorageGroup.OUTPUT, 4);
    this.inventory.addSlot(this.chargeSlot, StorageGroup.INTERNAL);
    addAugmentSlots(ThermalCoreConfig.machineAugments);
    initHandlers();
  }
  
  protected int getBaseProcessTick() {
    return SmelterRecipeManager.instance().getBasePower();
  }
  
  protected boolean cacheRecipe() {
    this.curRecipe = SmelterRecipeManager.instance().getRecipe((IThermalInventory)this);
    this.curCatalyst = SmelterRecipeManager.instance().getCatalyst((IItemStackHolder)this.catalystSlot);
    if (this.curRecipe != null)
      this.itemInputCounts = this.curRecipe.getInputItemCounts((IMachineInventory)this); 
    return (this.curRecipe != null);
  }
  
  protected void resolveInputs() {
    for (int i = 0; i < 3; i++)
      this.inputSlots[i].modify(-((Integer)this.itemInputCounts.get(i)).intValue()); 
    if (this.cyclicProcessingFeature && !this.catalystSlot.isEmpty() && !this.catalystSlot.isFull()) {
      ItemStack catalyst = this.catalystSlot.getItemStack();
      for (ItemStorageCoFH slot : outputSlots()) {
        if (ItemHelper.itemsEqualWithTags(slot.getItemStack(), catalyst)) {
          slot.modify(-1);
          this.catalystSlot.modify(1);
          break;
        } 
      } 
    } 
    int decrement = (this.itemInputCounts.size() > 3) ? ((Integer)this.itemInputCounts.get(3)).intValue() : 0;
    if (decrement > 0)
      if (this.catalystSlot.getItemStack().m_41763_()) {
        if (this.catalystSlot.getItemStack().m_41629_(decrement, MathHelper.RANDOM, null))
          this.catalystSlot.modify(-1); 
      } else {
        this.catalystSlot.modify(-decrement);
      }  
  }
  
  @Nullable
  public AbstractContainerMenu m_7208_(int i, Inventory inventory, Player player) {
    return (AbstractContainerMenu)new MachineSmelterContainer(i, this.f_58857_, this.f_58858_, inventory, player);
  }
  
  protected Object getSound() {
    return new ConditionalSoundInstance((SoundEvent)TExpSounds.SOUND_MACHINE_SMELTER.get(), SoundSource.AMBIENT, (BlockEntity)this, () -> Boolean.valueOf((!this.f_58859_ && this.isActive)));
  }
  
  protected boolean validateInputs() {
    if (!cacheRecipe())
      return false; 
    List<? extends ItemStorageCoFH> slotInputs = inputSlots();
    for (int i = 0; i < slotInputs.size() && i < this.itemInputCounts.size(); i++) {
      int inputCount = ((Integer)this.itemInputCounts.get(i)).intValue();
      if (((ItemStorageCoFH)slotInputs.get(i)).getItemStack().m_41613_() < inputCount)
        return false; 
    } 
    return true;
  }
  
  protected void resetAttributes() {
    super.resetAttributes();
    this.cyclicProcessingFeature = false;
  }
  
  protected void setAttributesFromAugment(CompoundTag augmentData) {
    super.setAttributesFromAugment(augmentData);
    this.cyclicProcessingFeature |= (AugmentableHelper.getAttributeMod(augmentData, "CycProc") > 0.0F) ? 1 : 0;
  }
}
